"use client";

import React, { useEffect, useState } from 'react';
import Link from 'next/link';
import Head from 'next/head'; 
import AdSense from '@/app/components/AdSense';

interface AfricanMovie {
  id: string;
  title: string;
  country: string;
}

const AfricanMoviesPage: React.FC = () => {
  const [africanMovies, setAfricanMovies] = useState<AfricanMovie[]>([]);
  const [filteredMovies, setFilteredMovies] = useState<AfricanMovie[]>([]);
  const [searchQuery, setSearchQuery] = useState("");
  const [selectedCountry, setSelectedCountry] = useState("");
  const [itemsToShow, setItemsToShow] = useState(40);
  const [currentPage, setCurrentPage] = useState(1);
  const [hasMorePages, setHasMorePages] = useState(true);
  const [countries, setCountries] = useState<string[]>([]);

  useEffect(() => {
    const calculateItemsToShow = () => {
      const screenWidth = window.innerWidth;
      if (screenWidth >= 1024) {
        setItemsToShow(40); // 40 items for PC
      } else {
        setItemsToShow(21); // 21 items for mobile
      }
    };

    calculateItemsToShow();
    window.addEventListener('resize', calculateItemsToShow);

    return () => {
      window.removeEventListener('resize', calculateItemsToShow);
    };
  }, []);

  useEffect(() => {
    const fetchAfricanMovies = async () => {
      try {
        const response = await fetch('/data/african.json');
        const data: AfricanMovie[] = await response.json();

        setAfricanMovies(data);
        setFilteredMovies(data.slice(0, itemsToShow)); // Initially show the first set of movies

        // Get unique countries for the filter dropdown
        const uniqueCountries: string[] = Array.from(new Set(data.map(movie => movie.country)));
        setCountries(uniqueCountries);
      } catch (error) {
        console.error('Failed to fetch African movies:', error);
      }
    };

    fetchAfricanMovies();
  }, [itemsToShow]);

  const handleLoadMore = () => {
    const newItemsToShow = itemsToShow + 20; // Load 20 more items on each click
    setFilteredMovies(africanMovies.slice(0, newItemsToShow));
    setItemsToShow(newItemsToShow);
    setHasMorePages(newItemsToShow < africanMovies.length);
  };

  useEffect(() => {
    const filtered = africanMovies.filter((item) =>
      item.title.toLowerCase().includes(searchQuery.toLowerCase()) &&
      (selectedCountry === "" || item.country === selectedCountry)
    );
    setFilteredMovies(filtered.slice(0, itemsToShow));
  }, [searchQuery, selectedCountry, africanMovies, itemsToShow]);

  const handleSearch = (e: React.ChangeEvent<HTMLInputElement>) => {
    setSearchQuery(e.target.value);
  };

  const handleCountryChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    setSelectedCountry(e.target.value);
  };

  return (
    <>
      <Head>
        <title>African Movies & Dramas - Delgor</title>
        <meta name="description" content="Discover and watch the best African movies and dramas. Explore content from various African countries and enjoy the richness of African cinema." />
        <link rel="canonical" href="https://www.delgor.com/african-movies" />
        <meta property="og:title" content="African Movies & Dramas - Delgor" />
        <meta property="og:description" content="Discover and watch the best African movies and dramas on Delgor. Explore content from various African countries and enjoy the richness of African cinema." />
        <meta property="og:type" content="website" />
        <meta property="og:url" content="https://www.delgor.com/african-movies" />
        <meta property="og:image" content="/images/african-movies-og.jpg" />
        <meta property="og:image:alt" content="African Movies & Dramas" />
        <meta property="og:site_name" content="Delgor" />
        {/* Structured Data */}
        <script type="application/ld+json">
          {JSON.stringify({
            "@context": "https://schema.org",
            "@type": "Movie",
            "name": "African Movies & Dramas",
            "description": "Discover and watch the best African movies and dramas on Delgor.",
            "url": "https://www.delgor.com/africanmovies",
            "image": "/images/african-movies-og.jpg",
          })}
        </script>
      </Head>
      <div className="relative mt-0 md:mt-24">
        {/* Top Section with a featured African Movie, Search Bar, and Country Filter */}
        <div className="relative mb-8 md:mb-12">
          <div className="relative bg-white bg-opacity-90 p-4 flex justify-center items-center h-48 md:h-72">
            <div className="absolute bottom-0 w-full h-16 bg-gradient-to-b from-transparent to-black"></div>
            <h1 className="text-3xl font-bold text-center text-black mt-0 md:mt-2">
              Your Place For African Movie & Drama
            </h1>
          </div>

          <div className="absolute bottom-0 left-1/2 transform -translate-x-1/2 translate-y-1/2 w-4/5">
            <div className="flex flex-col md:flex-row justify-center items-center space-y-4 md:space-y-0 md:space-x-4">
              <input
                type="text"
                value={searchQuery}
                onChange={handleSearch}
                placeholder="Search for African Movies"
                className="w-full md:w-4/5 bg-black text-white p-4 rounded-lg border-2 border-red-600 focus:outline-none transition-all duration-300 ease-in-out text-base md:text-lg"
              />
              <select
                value={selectedCountry}
                onChange={handleCountryChange}
                className="w-full md:w-1/5 bg-black text-white p-4 rounded-lg border-2 border-red-600 focus:outline-none transition-all duration-300 ease-in-out text-base md:text-lg"
              >
                <option value="">By Country</option>
                {countries.map((country) => (
                  <option key={country} value={country}>
                    {country}
                  </option>
                ))}
              </select>
            </div>
          </div>
        </div>

        {/* Movie Grid with adjusted margin for mobile */}
        <div className="mt-32 md:mt-12 grid grid-cols-3 sm:grid-cols-3 md:grid-cols-5 lg:grid-cols-8 gap-4 px-4 animate-fadeIn">
          {filteredMovies.map((movie) => {
            const slug = movie.title.toLowerCase().replace(/ /g, '-');
            const url = `/watch/afriq?videoId=${movie.id}`;

            return (
              <Link key={movie.id} href={url} passHref>
                <div className="relative cursor-pointer animate-filter group">
                  <div className="absolute inset-0 w-full h-full rounded-lg overflow-hidden">
                    <img
                      src={`https://img.youtube.com/vi/${movie.id}/hqdefault.jpg`}
                      alt={movie.title}
                      className="w-full h-full object-cover filter blur-md transform scale-150"
                    />
                  </div>
                  <div className="relative z-10 flex justify-center items-center h-[180px] md:h-[280px]">
                    <img
                      src={`https://img.youtube.com/vi/${movie.id}/hqdefault.jpg`}
                      alt={movie.title}
                      className="max-w-full max-h-full object-contain rounded-lg shadow-lg transition-transform duration-300 ease-in-out transform group-hover:scale-105"
                    />
                  </div>
                  <div className="absolute top-2 right-2 bg-black bg-opacity-70 text-xs px-2 py-1 rounded flex items-center z-20">
                    <img
                      src={`/flags/${movie.country.toLowerCase()}.png`}
                      alt={movie.country}
                      className="w-6 h-4 mr-2"
                    />
                    {movie.country}
                  </div>
                </div>
              </Link>
            );
          })}
        </div>

        {/* Load More Button */}
        {hasMorePages && (
          <div className="flex justify-center mt-8">
            <button
              onClick={handleLoadMore}
              className="px-4 py-2 bg-red-600 text-white rounded hover:bg-red-700"
            >
              Load More
            </button>
          </div>
        )}

        <div className="hidden md:block h-12"></div>

        <style jsx>{`
          .animate-fadeIn {
            animation: fadeIn 1s ease-in-out;
          }

          .animate-filter {
            animation: filter 0.5s ease-in-out;
          }

          @keyframes fadeIn {
            from {
              opacity: 0;
              transform: translateY(20px);
            }
            to {
              opacity: 1;
              transform: translateY(0);
            }
          }

          @keyframes filter {
            from {
              opacity: 0.5;
              transform: scale(0.95);
            }
            to {
              opacity: 1;
              transform: scale(1);
            }
          }
        `}</style>
      </div>
      <div className="w-full my-8">
          <AdSense />
      </div>
    </>
  );
};

export default AfricanMoviesPage;
